.layouts_layout__1mtTi{display:flex;min-height:100vh;background:var(--bg)}.layouts_contentContainer__h0N8M{flex:1;min-height:100vh;background:var(--bg)}.layouts_mainContent__gZF9G{padding:1.5rem;margin-top:-.5rem;margin-left:16rem;background:var(--bg);border-top-left-radius:var(--radius-large)}.layouts_topHeader__yFoVb{padding:.75rem;background:var(--bg2);height:4.25rem}.layouts_topHeaderContent__Rynf2{display:flex;height:1rem}.layouts_overlay__YYdpM{display:none;position:fixed;top:0;left:0;right:0;bottom:0;background:rgba(0,0,0,.5);z-index:40}@media (max-width:768px){.layouts_mainContent__gZF9G{margin-left:0}.layouts_overlay__YYdpM.layouts_active__GuO91{display:block}}